pycocoa.screens.Screen

Package pycocoa :: Module screens :: Class Screen |
[frames] | no frames]

# Class Screen

      object --+
               |
    bases._Type0 --+
                   |
                  Screen

Known Subclasses:
  - BuiltInScreen
  - , DeepestScreen
  - , ExternalScreen
  - , MainScreen

Screen Python Type, wrapping ObjC NSRect_t.

Instance Methods
__eq__(self, other) |
cascade(self, fraction=0.1) Return a screen point off the upper left corner. |
Inherited from `bases._Type0`: `__init__`, `__repr__`, `__str__`, `type2strepr` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Static Methods
a new object with type S, a subtype of T |
__new__(cls, screen=None, name=`'````'`) |

Properties
| bottom Get the lower y coordinate (`float` or `int`).
| bottomleft Get the lower left corner (Point).
| bottomright Get the lower right corner (Point).
| center Get the center (Point).
| colorSpace Get the device color space (`str`).
| deviceDescription Get the device descriptions (Adict).
| deviceDict Get the device descriptions (Adict).
| displayID Get the `displayID` aka `NSScreenNumber` of this screen (`int`).
| frame Get the frame (Rect).
| isBuiltIn Is this the single, BuiltIn screen (`bool`)?
| isExternal Is this screen an External one (`bool`)?
| isPrinter Is this screen a printer (`bool` or `None`)?
| isScreen Is this screen a monitor (`bool` or `None`)?
| left Get the leftmost x coordinate (`float` or `int`).
| name Get the screen name (`str`).
| named Get the localized name (`str`).
| origin Get the origin (Point).
| pixels Get the device width and height pixel count (`Size`).
| ratio Get the aspect ratio (`2-tuple(wide, high)`).
| resolutions Get the device width and height resolution in DPI (`Size`).
| right Get the rightmost x coordinate (`float` or `int`).
| size Get the width and height (Size).
| top Get the upper y coordinate (`float` or `int`).
| topleft Get the upper left corner (Point).
| topright Get the upper right corner (Point).
| visibleFrame Get the fram of the visible area (Frame).
Inherited from `bases._Type0`: `NS`, `NSDelegate` Inherited from `object`: `__class__`

Method Details

### __new__(cls, screen=None, name=`'````'`) Static Method |
Returns: a new object with type S, a subtype of T Overrides: object.__new__ (inherited documentation)

### cascade(self, fraction=0.1) |
Return a screen point off the upper left corner. Parameters: `fraction` - Of the size (`float`). Returns: The screen point (Point).

Property Details

### bottom Get the lower y coordinate (`float` or `int`). Get Method: bottom(self) - Get the lower y coordinate (`float` or `int`). Set Method: Read_Only(self, ignored) - Throws an `AttributeError`, always.

### bottomleft Get the lower left corner (Point). Get Method: bottomleft(self) - Get the lower left corner (Point). Set Method: Read_Only(self, ignored) - Throws an `AttributeError`, always.

### bottomright Get the lower right corner (Point). Get Method: bottomright(self) - Get the lower right corner (Point). Set Method: Read_Only(self, ignored) - Throws an `AttributeError`, always.

### center Get the center (Point). Get Method: center(self) - Get the center (Point). Set Method: Read_Only(self, ignored) - Throws an `AttributeError`, always.

### colorSpace Get the device color space (`str`). Get Method: colorSpace(self) - Get the device color space (`str`). Set Method: Read_Only(self, ignored) - Throws an `AttributeError`, always.

### deviceDescription Get the device descriptions (Adict). Get Method: deviceDescription(self) - Get the device descriptions (Adict). Set Method: Read_Only(self, ignored) - Throws an `AttributeError`, always.

### deviceDict Get the device descriptions (Adict). Get Method: deviceDescription(self) - Get the device descriptions (Adict). Set Method: Read_Only(self, ignored) - Throws an `AttributeError`, always.

### displayID Get the `displayID` aka `NSScreenNumber` of this screen (`int`). Get Method: displayID(self) - Get the `displayID` aka `NSScreenNumber` of this screen (`int`). Set Method: Read_Only(self, ignored) - Throws an `AttributeError`, always.

### frame Get the frame (Rect). Get Method: frame(self) - Get the frame (Rect). Set Method: frame(self, rect) - Set the rect (Rect, `2-list`, `4-list`, `2-tuple`, `4-tuple` or `NSRect[4]_t`).

### isBuiltIn Is this the single, BuiltIn screen (`bool`)? Get Method: isBuiltIn(self) - Is this the single, BuiltIn screen (`bool`)? Set Method: Read_Only(self, ignored) - Throws an `AttributeError`, always.

### isExternal Is this screen an External one (`bool`)? Get Method: isExternal(self) - Is this screen an External one (`bool`)? Set Method: Read_Only(self, ignored) - Throws an `AttributeError`, always.

### isPrinter Is this screen a printer (`bool` or `None`)? Get Method: isPrinter(self) - Is this screen a printer (`bool` or `None`)? Set Method: Read_Only(self, ignored) - Throws an `AttributeError`, always.

### isScreen Is this screen a monitor (`bool` or `None`)? Get Method: isScreen(self) - Is this screen a monitor (`bool` or `None`)? Set Method: Read_Only(self, ignored) - Throws an `AttributeError`, always.

### left Get the leftmost x coordinate (`float` or `int`). Get Method: left(self) - Get the leftmost x coordinate (`float` or `int`). Set Method: Read_Only(self, ignored) - Throws an `AttributeError`, always.

### name Get the screen name (`str`). Get Method: name(self) - Get the screen name (`str`). Set Method: Read_Only(self, ignored) - Throws an `AttributeError`, always.

### named Get the localized name (`str`). Get Method: named(self) - Get the localized name (`str`). Set Method: Read_Only(self, ignored) - Throws an `AttributeError`, always.

### origin Get the origin (Point). Get Method: origin(self) - Get the origin (Point). Set Method: Read_Only(self, ignored) - Throws an `AttributeError`, always.

### pixels Get the device width and height pixel count (`Size`). Get Method: pixels(self) - Get the device width and height pixel count (`Size`). Set Method: Read_Only(self, ignored) - Throws an `AttributeError`, always.

### ratio Get the aspect ratio (`2-tuple(wide, high)`). Get Method: ratio(self) - Get the aspect ratio (`2-tuple(wide, high)`). Set Method: Read_Only(self, ignored) - Throws an `AttributeError`, always.

### resolutions Get the device width and height resolution in DPI (`Size`). Get Method: resolutions(self) - Get the device width and height resolution in DPI (`Size`). Set Method: Read_Only(self, ignored) - Throws an `AttributeError`, always.

### right Get the rightmost x coordinate (`float` or `int`). Get Method: right(self) - Get the rightmost x coordinate (`float` or `int`). Set Method: Read_Only(self, ignored) - Throws an `AttributeError`, always.

### size Get the width and height (Size). Get Method: size(self) - Get the width and height (Size). Set Method: Read_Only(self, ignored) - Throws an `AttributeError`, always.

### top Get the upper y coordinate (`float` or `int`). Get Method: top(self) - Get the upper y coordinate (`float` or `int`). Set Method: Read_Only(self, ignored) - Throws an `AttributeError`, always.

### topleft Get the upper left corner (Point). Get Method: topleft(self) - Get the upper left corner (Point). Set Method: Read_Only(self, ignored) - Throws an `AttributeError`, always.

### topright Get the upper right corner (Point). Get Method: topright(self) - Get the upper right corner (Point). Set Method: Read_Only(self, ignored) - Throws an `AttributeError`, always.

### visibleFrame Get the fram of the visible area (Frame). Get Method: visibleFrame(self) - Get the fram of the visible area (Frame). Set Method: Read_Only(self, ignored) - Throws an `AttributeError`, always.